# ifndef yyDependences
# define yyDependences

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 53 "Dependences.puma" */


#include "pred.h"
#include "Nesting.h"   /* pointer to loop nest */
#include "ExpNormal.h" /* type ExpNormRecord   */

typedef PredVector* pPredVector;



extern void (* Dependences_Exit) ARGS ((void));

extern void Dependences ARGS ((tTree e1, ptree loops1, int n1, tTree e2, ptree loops2, int n2, int CommonLoops, int ConstLoops, ptree params, int np, pPredVector p));

extern void BeginDependences ARGS ((void));
extern void CloseDependences ARGS ((void));

# endif
